"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const components_1 = require("./components");
const Tools = require("./generator");
const styles = require("./style.scss");
const getClassNames = (className) => {
    return className
        .split(" ")
        .map(name => styles[name])
        .join(" ");
};
class App extends React.Component {
    constructor(props) {
        super(props);
        this.npmUrl = "https://www.npmjs.com/package/npm-run-script-chain";
        this.state = {
            raw: props.raw,
            key: "start",
        };
    }
    render() {
        const menu = this.generateMenu(this.props.raw);
        const treeData = this.getTreeData();
        const onClick = this.updateKey.bind(this);
        return (React.createElement(React.Fragment, null,
            React.createElement("nav", { className: getClassNames("navbar navbar-dark fixed-top bg-dark flex-md-nowrap p-0 shadow") },
                React.createElement("a", { className: getClassNames("navbar-brand col-sm-3 col-md-2 mr-0"), href: this.npmUrl, target: "_blank", rel: "noopener" }, "npm-run-script-chain")),
            React.createElement("div", { className: styles.containerFluid },
                React.createElement("div", { className: styles.row },
                    React.createElement("nav", { className: getClassNames("col-md-2 d-none d-md-block bg-light sidebar") },
                        React.createElement("div", { className: styles["sidebar-sticky"] }, menu)),
                    React.createElement("main", { className: getClassNames("col-md-9 ml-sm-auto col-lg-10 px-4") },
                        React.createElement("div", { className: getClassNames("d-flex justify-content-between flex-wrap flex-md-nowrap align-items-center pt-3 pb-2 mb-3 border-bottom") },
                            React.createElement("h1", { className: styles.h2 }, this.state.key)),
                        treeData && React.createElement(components_1.Tree.Component, Object.assign({}, { treeData, onClick })))))));
    }
    updateKey(key) {
        this.setState({
            key,
        });
    }
    getTreeData() {
        return Tools.generateTreeData(this.state.key, this.props.raw);
    }
    generateMenu(pkg) {
        const buttons = Object.keys(pkg.scripts).map(key => {
            const props = {
                text: key,
                isActive: key === this.state.key,
                onClick: () => {
                    this.setState({
                        key,
                    });
                },
            };
            return props;
        });
        return components_1.Button.createElements(buttons);
    }
}
exports.Component = App;
//# sourceMappingURL=App.js.map