"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const React = require("react");
const Button = require("./Button");
const PathTree = require("paths-js/tree");
const DEFAULT_TREE_PARAMS = {
    tree: {
        curves: [],
        nodes: [],
    },
    size: {
        width: 960,
        height: 540,
    },
};
exports.DEFAULT_PROPS = DEFAULT_TREE_PARAMS;
const generateTreeParams = (data, size) => {
    if (!data) {
        return DEFAULT_TREE_PARAMS;
    }
    return {
        tree: PathTree({
            data,
            children,
            width: size.width,
            height: size.height,
        }),
        size,
    };
};
const children = (x) => {
    if (x.collapsed) {
        return [];
    }
    else {
        return x.children || [];
    }
};
exports.children = children;
class Tree extends React.Component {
    render() {
        const params = generateTreeParams(this.props.treeData, DEFAULT_TREE_PARAMS.size);
        return (React.createElement("div", { id: "tree" },
            React.createElement("svg", { width: `${params.size.width}px`, height: `${params.size.height}px` },
                React.createElement("g", { transform: "translate(100, 40) scale(0.75)" },
                    this.curves(params),
                    this.nodes(params, this.props.onClick)))));
    }
    curves(params) {
        return params.tree.curves.map((c, idx) => {
            return React.createElement("path", { key: `curves-${idx}`, d: c.connector.path.print(), fill: "none", stroke: "gray" });
        });
    }
    nodes(params, onClick) {
        return params.tree.nodes.map((n, idx) => {
            const x = isNaN(n.point[0]) ? 0 : n.point[0];
            const y = isNaN(n.point[0]) ? DEFAULT_TREE_PARAMS.size.height / 2 : n.point[1];
            const position = "translate(" + x + "," + y + ")";
            const toggle = () => {
                n.item.collapsed = !n.item.collapsed;
                this.forceUpdate();
            };
            const text = Button.createTextNode(n, { x: children(n.item).length > 0 ? -10 : 10, y: 0 }, onClick);
            return (React.createElement("g", { transform: position, key: `node-${idx}` },
                React.createElement("circle", { fill: "white", stroke: "black", r: "5", cx: "0", cy: "0", onClick: toggle }),
                text));
        });
    }
}
exports.Component = Tree;
//# sourceMappingURL=Tree.js.map