"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const NPM_RUN = /^npm run /;
const YARN_RUN = /^yarn run /;
const RUN_P = /^run-p /;
const makeTreeData = (key) => ({
    name: key,
    children: [],
});
const getFormatScript = (script) => {
    return {
        key: script
            .trim()
            .replace(NPM_RUN, "")
            .replace(RUN_P, "")
            .replace(YARN_RUN, ""),
        option: {
            run_p: script.trim().match(RUN_P) !== null,
        },
    };
};
const getSplitScripts = (runScriptString, splitPattern = "&&") => {
    const scripts = runScriptString.split(splitPattern);
    return scripts.map(getFormatScript);
};
exports.makeChildChain = (parentResult, scripts, pkg, deleteKeys) => {
    scripts.forEach(childScript => {
        const childResult = makeTreeData(childScript.key);
        if (childScript.option.run_p && childScript.key.match(/\*/) !== null) {
            const pt = childScript.key.replace(/\*/, "(.+)");
            const regex = new RegExp(pt);
            const parallelScript = makeTreeData(childScript.key);
            for (const pkgKey in pkg.scripts) {
                if (pkgKey.match(regex) !== null) {
                    const subChildScript = makeTreeData(pkgKey);
                    exports.makeChain(subChildScript, pkg, deleteKeys);
                    parallelScript.children.push(subChildScript);
                }
            }
            parentResult.children.push(parallelScript);
        }
        else if (childScript.option.run_p && childScript.key.match(/\*/) === null) {
            const childScripts = getSplitScripts(childScript.key, " ");
            exports.makeChildChain(parentResult, childScripts, pkg, deleteKeys);
        }
        else if (childResult.name in pkg.scripts) {
            exports.makeChain(childResult, pkg, deleteKeys);
            parentResult.children.push(childResult);
        }
    });
};
exports.makeChain = (parentResult, pkg, deleteKeys = []) => {
    const startKey = parentResult.name;
    if (!(startKey in pkg.scripts) || deleteKeys.includes(startKey)) {
        return;
    }
    deleteKeys.push(startKey);
    const runScriptString = pkg.scripts[startKey];
    const childScripts = getSplitScripts(runScriptString);
    exports.makeChildChain(parentResult, childScripts, pkg, deleteKeys);
};
//# sourceMappingURL=parser.js.map